@@ -167,6 +167,7 @@ AP_DECLARE(int) ap_is_initial_req(request_rec *r) {
 	return 0;
 }
 
+#if MODULE_MAGIC_NUMBER_MAJOR >= 20100714
 AP_DECLARE(ap_expr_info_t *) ap_expr_parse_cmd_mi(const cmd_parms *cmd, const char *expr,
 		unsigned int flags, const char **err, ap_expr_lookup_fn_t *lookup_fn,
 		int module_index) {
@@ -179,7 +180,6 @@ AP_DECLARE(const char *) ap_expr_str_exec(request_rec *r, const ap_expr_info_t *
 	return expr->filename;
 }
 
-#if MODULE_MAGIC_NUMBER_MAJOR >= 20100714
 AP_DECLARE(void) ap_log_error_(const char *file, int line, int module_index,
 		int level, apr_status_t status, const server_rec *s, const char *fmt,
 		...) {
@@ -297,3 +297,9 @@ AP_DECLARE(void) ap_log_error_(const char *file, int line, int module_index,
 				ap_filter_type ftype) {
 			return NULL;
 		}
+
+		AP_DECLARE(int) ap_expr_exec(request_rec *r, const ap_expr_info_t *expr,
+				const char **err) {
+			return 0;
+		}
+
